@@ -98,12 +98,18 @@ class HttpPrinter(object):
             self.buf = StringIO()
             if value:
                 print("[%s:%d] -- -- --> [%s:%d] " % (self.client_host[0], self.client_host[1],
-                                                       self.remote_host[0], self.remote_host[1]),
+                                                      self.remote_host[0], self.remote_host[1]),
                       file=config.out)
                 print(value.encode('utf8'), file=config.out)
                 config.out.flush()
         except IOError as e:
-            sys.exit(0)
+            if e.errno == 32:
+                # may be pipe closed
+                sys.exit(0)
+            else:
+                print(e, file=sys.stderr)
+                sys.exit(-1)
+
         finally:
             printer_lock.release()
 
